# The XBR Protocol

[![Docs (on CDN)](https://img.shields.io/badge/docs-cdn-brightgreen.svg?style=flat)](https://xbr.network/docs/index.html) &nbsp; [![Docs (on S3)](https://img.shields.io/badge/docs-s3-brightgreen.svg?style=flat)](https://s3.eu-central-1.amazonaws.com/xbr.foundation/docs/index.html) &nbsp; [![Travis](https://travis-ci.org/xbr/xbr-protocol.svg?branch=master)](https://travis-ci.org/xbr/xbr-protocol)

This repository contains the XBR smart contracts, with Ethereum as target blockchain, and Solidity as implementation language for the **XBR Protocol**.

Please see the [documentation](https://xbr.network/docs/index.html) for more information.

Copyright Crossbar.io Technologies GmbH. Licensed under the [Apache 2.0 license](https://www.apache.org/licenses/LICENSE-2.0).

---
